@@ -24,6 +24,7 @@
 #include <QMainWindow>
 #include <QProgressBar>
 #include <QSystemTrayIcon>
+#include <QTimer>
 
 #include "core/SignalMultiplexer.h"
 #include "gui/DatabaseWidget.h"
@@ -52,6 +53,7 @@ public:
 
     QList<DatabaseWidget*> getOpenDatabases();
     void restoreConfigState();
+    void setAllowScreenCapture(bool state);
 
     enum StackedWidgetIndex
     {
@@ -95,6 +97,8 @@ public slots:
     void restartApp(const QString& message);
 
 protected:
+    void showEvent(QShowEvent* event) override;
+    void hideEvent(QHideEvent* event) override;
     void closeEvent(QCloseEvent* event) override;
     void changeEvent(QEvent* event) override;
     void keyPressEvent(QKeyEvent* event) override;
@@ -121,9 +125,6 @@ private slots:
     void switchToNewDatabase();
     void switchToOpenDatabase();
     void switchToDatabaseFile(const QString& file);
-    void switchToKeePass1Database();
-    void switchToOpVaultDatabase();
-    void switchToCsvImport();
     void databaseStatusChanged(DatabaseWidget* dbWidget);
     void databaseTabChanged(int tabIndex);
     void openRecentDatabase(QAction* action);
@@ -192,6 +193,7 @@ private:
     bool m_restartRequested = false;
     bool m_contextMenuFocusLock = false;
     bool m_showToolbarSeparator = false;
+    bool m_allowScreenCapture = false;
     qint64 m_lastFocusOutTime = 0;
     qint64 m_lastShowTime = 0;
     QTimer m_updateCheckTimer;
